load_sound_alias

Function load_sound_alias 

pub unsafe extern "C" fn load_sound_alias(source: Sound) -> Sound
Create a new sound that shares the same sample data as the source sound, does not own the sound data